@@ -53,11 +53,11 @@ class BaseDatabaseCreation:
             package_label=None,
             migration_name=None,
             fake=False,
-            fake_initial=False,
             plan=False,
             check_unapplied=False,
             backup=False,
             prune=False,
+            no_input=True,
             verbosity=max(verbosity - 1, 0),
         )
 
@@ -96,7 +96,7 @@ class BaseDatabaseCreation:
     #                     ) and router.allow_migrate_model(self.connection.alias, model):
     #                         queryset = model._base_manager.using(
     #                             self.connection.alias,
-    #                         ).order_by(model._meta.pk.name)
+    #                         ).order_by("id")
     #                         yield from queryset.iterator()
 
     #     # Serialize to a string
