@@ -29,11 +29,11 @@ def _is_relevant_relation(relation, altered_field):
     if field.many_to_many:
         # M2M reverse field
         return False
-    if altered_field.primary_key and field.to_fields == [None]:
+    if altered_field.primary_key:
         # Foreign key constraint on the primary key, which is being altered.
         return True
-    # Is the constraint targeting the field being altered?
-    return altered_field.name in field.to_fields
+    # ForeignKey always targets 'id'
+    return altered_field.name == "id"
 
 
 def _all_related_fields(model):
@@ -239,11 +239,7 @@ class BaseDatabaseSchemaEditor:
             column_sqls.append(f"{self.quote_name(field.column)} {definition}")
             # Autoincrement SQL (for backends with post table definition
             # variant).
-            if field.get_internal_type() in (
-                "AutoField",
-                "BigAutoField",
-                "SmallAutoField",
-            ):
+            if field.get_internal_type() in ("PrimaryKeyField",):
                 autoinc_sql = self.connection.ops.autoinc_sql(
                     model._meta.db_table, field.column
                 )
