@@ -1,13 +1,14 @@
 import copy
 from decimal import Decimal
 
+from plain.models import register_model
 from plain.models.backends.base.schema import BaseDatabaseSchemaEditor
 from plain.models.backends.ddl_references import Statement
 from plain.models.backends.utils import strip_quotes
 from plain.models.constraints import UniqueConstraint
 from plain.models.db import NotSupportedError
+from plain.models.registry import ModelsRegistry
 from plain.models.transaction import atomic
-from plain.packages.registry import Packages
 
 
 class DatabaseSchemaEditor(BaseDatabaseSchemaEditor):
@@ -57,14 +58,14 @@ class DatabaseSchemaEditor(BaseDatabaseSchemaEditor):
         elif isinstance(value, Decimal | float | int):
             return str(value)
         elif isinstance(value, str):
-            return "'%s'" % value.replace("'", "''")
+            return "'{}'".format(value.replace("'", "''"))
         elif value is None:
             return "NULL"
         elif isinstance(value, bytes | bytearray | memoryview):
             # Bytes are only allowed for BLOB fields, encoded as string
             # literals containing hexadecimal data and preceded by a single "X"
             # character.
-            return "X'%s'" % value.hex()
+            return f"X'{value.hex()}'"
         else:
             raise ValueError(
                 f"Cannot quote parameter value {value!r} of type {type(value)}"
@@ -106,12 +107,9 @@ class DatabaseSchemaEditor(BaseDatabaseSchemaEditor):
         ):
             if self.connection.in_atomic_block:
                 raise NotSupportedError(
-                    (
-                        "Renaming the %r table while in a transaction is not "
-                        "supported on SQLite < 3.26 because it would break referential "
-                        "integrity. Try adding `atomic = False` to the Migration class."
-                    )
-                    % old_db_table
+                    f"Renaming the {old_db_table!r} table while in a transaction is not "
+                    "supported on SQLite < 3.26 because it would break referential "
+                    "integrity. Try adding `atomic = False` to the Migration class."
                 )
             self.connection.enable_constraint_checking()
             super().alter_db_table(model, old_db_table, new_db_table)
@@ -134,13 +132,11 @@ class DatabaseSchemaEditor(BaseDatabaseSchemaEditor):
         ):
             if self.connection.in_atomic_block:
                 raise NotSupportedError(
-                    (
-                        "Renaming the {!r}.{!r} column while in a transaction is not "
-                        "supported on SQLite < 3.26 because it would break referential "
-                        "integrity. Try adding `atomic = False` to the Migration class."
-                    ).format(model._meta.db_table, old_field_name)
+                    f"Renaming the {model._meta.db_table!r}.{old_field_name!r} column while in a transaction is not "
+                    "supported on SQLite < 3.26 because it would break referential "
+                    "integrity. Try adding `atomic = False` to the Migration class."
                 )
-            with atomic(self.connection.alias):
+            with atomic():
                 super().alter_field(model, old_field, new_field, strict=strict)
                 # Follow SQLite's documented procedure for performing changes
                 # that don't affect the on-disk content.
@@ -150,7 +146,7 @@ class DatabaseSchemaEditor(BaseDatabaseSchemaEditor):
                         0
                     ]
                     cursor.execute("PRAGMA writable_schema = 1")
-                    references_template = ' REFERENCES "%s" ("%%s") ' % table_name
+                    references_template = f' REFERENCES "{table_name}" ("%s") '
                     new_column_name = new_field.get_attname_column()[1]
                     search = references_template % old_column_name
                     replacement = references_template % new_column_name
@@ -158,7 +154,7 @@ class DatabaseSchemaEditor(BaseDatabaseSchemaEditor):
                         "UPDATE sqlite_master SET sql = replace(sql, %s, %s)",
                         (search, replacement),
                     )
-                    cursor.execute("PRAGMA schema_version = %d" % (schema_version + 1))
+                    cursor.execute("PRAGMA schema_version = %d" % (schema_version + 1))  # noqa: UP031
                     cursor.execute("PRAGMA writable_schema = 0")
                     # The integrity check will raise an exception and rollback
                     # the transaction if the sqlite_master updates corrupt the
@@ -240,11 +236,8 @@ class DatabaseSchemaEditor(BaseDatabaseSchemaEditor):
             body.pop(old_field.name, None)
             mapping.pop(old_field.column, None)
             body[new_field.name] = new_field
-            if old_field.null and not new_field.null:
-                case_sql = "coalesce({col}, {default})".format(
-                    col=self.quote_name(old_field.column),
-                    default=self.prepare_default(self.effective_default(new_field)),
-                )
+            if old_field.allow_null and not new_field.allow_null:
+                case_sql = f"coalesce({self.quote_name(old_field.column)}, {self.prepare_default(self.effective_default(new_field))})"
                 mapping[new_field.column] = case_sql
             else:
                 mapping[new_field.column] = self.quote_name(old_field.column)
@@ -252,14 +245,8 @@ class DatabaseSchemaEditor(BaseDatabaseSchemaEditor):
         if delete_field:
             del body[delete_field.name]
             del mapping[delete_field.column]
-            # Remove any implicit M2M tables
-            if (
-                delete_field.many_to_many
-                and delete_field.remote_field.through._meta.auto_created
-            ):
-                return self.delete_model(delete_field.remote_field.through)
         # Work inside a new app registry
-        packages = Packages()
+        models_registry = ModelsRegistry()
 
         indexes = model._meta.indexes
         if delete_field:
@@ -284,26 +271,27 @@ class DatabaseSchemaEditor(BaseDatabaseSchemaEditor):
             "db_table": model._meta.db_table,
             "indexes": indexes,
             "constraints": constraints,
-            "packages": packages,
+            "models_registry": models_registry,
         }
         meta = type("Meta", (), meta_contents)
         body_copy["Meta"] = meta
         body_copy["__module__"] = model.__module__
-        type(model._meta.object_name, model.__bases__, body_copy)
+        register_model(type(model._meta.object_name, model.__bases__, body_copy))
 
         # Construct a model with a renamed table name.
         body_copy = copy.deepcopy(body)
         meta_contents = {
             "package_label": model._meta.package_label,
-            "db_table": "new__%s" % strip_quotes(model._meta.db_table),
+            "db_table": f"new__{strip_quotes(model._meta.db_table)}",
             "indexes": indexes,
             "constraints": constraints,
-            "packages": packages,
+            "models_registry": models_registry,
         }
         meta = type("Meta", (), meta_contents)
         body_copy["Meta"] = meta
         body_copy["__module__"] = model.__module__
-        new_model = type("New%s" % model._meta.object_name, model.__bases__, body_copy)
+        new_model = type(f"New{model._meta.object_name}", model.__bases__, body_copy)
+        register_model(new_model)
 
         # Create a new table with the updated schema.
         self.create_model(new_model)
@@ -357,19 +345,15 @@ class DatabaseSchemaEditor(BaseDatabaseSchemaEditor):
 
     def add_field(self, model, field):
         """Create a field on a model."""
-        # Special-case implicit M2M tables.
-        if field.many_to_many and field.remote_field.through._meta.auto_created:
-            self.create_model(field.remote_field.through)
-        elif (
-            # Primary keys and unique fields are not supported in ALTER TABLE
+        if (
+            # Primary keys are not supported in ALTER TABLE
             # ADD COLUMN.
             field.primary_key
-            or field.unique
             or
             # Fields with default values cannot by handled by ALTER TABLE ADD
             # COLUMN statement because DROP DEFAULT is not supported in
             # ALTER TABLE.
-            not field.null
+            not field.allow_null
             or self.effective_default(field) is not None
         ):
             self._remake_table(model, create_field=field)
@@ -383,17 +367,14 @@ class DatabaseSchemaEditor(BaseDatabaseSchemaEditor):
         """
         # M2M fields are a special case
         if field.many_to_many:
-            # For implicit M2M tables, delete the auto-created table
-            if field.remote_field.through._meta.auto_created:
-                self.delete_model(field.remote_field.through)
             # For explicit "through" M2M fields, do nothing
+            pass
         elif (
             self.connection.features.can_alter_table_drop_column
             # Primary keys, unique fields, indexed fields, and foreign keys are
             # not supported in ALTER TABLE DROP COLUMN.
             and not field.primary_key
-            and not field.unique
-            and not field.db_index
+            and not (field.remote_field and field.db_index)
             and not (field.remote_field and field.db_constraint)
         ):
             super().remove_field(model, field)
@@ -439,7 +420,7 @@ class DatabaseSchemaEditor(BaseDatabaseSchemaEditor):
         # Rebuild tables with FKs pointing to this field.
         old_collation = old_db_params.get("collation")
         new_collation = new_db_params.get("collation")
-        if new_field.unique and (
+        if new_field.primary_key and (
             old_type != new_type or old_collation != new_collation
         ):
             related_models = set()
@@ -451,15 +432,11 @@ class DatabaseSchemaEditor(BaseDatabaseSchemaEditor):
                 if not remote_field.many_to_many:
                     if remote_field.field_name == new_field.name:
                         related_models.add(remote_field.related_model)
-                elif new_field.primary_key and remote_field.through._meta.auto_created:
-                    related_models.add(remote_field.through)
             if new_field.primary_key:
                 for many_to_many in opts.many_to_many:
                     # Ignore self-relationship since the table was already rebuilt.
                     if many_to_many.related_model == model:
                         continue
-                    if many_to_many.remote_field.through._meta.auto_created:
-                        related_models.add(many_to_many.remote_field.through)
             for related_model in related_models:
                 self._remake_table(related_model)
 
