@@ -24,9 +24,8 @@ from plain.models.deletion import Collector
 from plain.models.expressions import RawSQL, Value
 from plain.models.fields import NOT_PROVIDED
 from plain.models.fields.reverse_related import ForeignObjectRel
-from plain.models.manager import Manager
 from plain.models.options import Options
-from plain.models.query import F, Q
+from plain.models.query import F, Q, QuerySet
 from plain.packages import packages_registry
 from plain.utils.encoding import force_str
 from plain.utils.hashable import make_hashable
@@ -75,7 +74,7 @@ class ModelBase(type):
         new_class._add_exceptions()
 
         # Now go back over all the attrs on this class see if they have a contribute_to_class() method.
-        # Attributes with contribute_to_class are fields, meta options, and managers.
+        # Attributes with contribute_to_class are fields and meta options.
         for attr_name, attr_value in inspect.getmembers(new_class):
             if attr_name.startswith("_"):
                 continue
@@ -161,16 +160,6 @@ class ModelBase(type):
                 ", ".join(f.name for f in opts.fields),
             )
 
-        if not opts.managers:
-            if any(f.name == "objects" for f in opts.fields):
-                raise ValueError(
-                    f"Model {cls.__name__} must specify a custom Manager, because it has a "
-                    "field named 'objects'."
-                )
-            manager = Manager()
-            manager.auto_created = True
-            cls.add_to_class("objects", manager)
-
         # Set the name of _meta.indexes. This can't be done in
         # Options.contribute_to_class() because fields haven't been added to
         # the model at that point.
@@ -179,12 +168,9 @@ class ModelBase(type):
                 index.set_name_with_model(cls)
 
     @property
-    def _base_manager(cls):
-        return cls._meta.base_manager
-
-    @property
-    def _default_manager(cls):
-        return cls._meta.default_manager
+    def query(cls) -> QuerySet:
+        """Create a new QuerySet for this model."""
+        return cls._meta.queryset
 
 
 class ModelStateFieldsCacheDescriptor:
@@ -207,6 +193,9 @@ class ModelState:
 
 
 class Model(metaclass=ModelBase):
+    DoesNotExist: type[ObjectDoesNotExist]
+    MultipleObjectsReturned: type[MultipleObjectsReturned]
+
     def __init__(self, *args, **kwargs):
         # Alias some things as locals to avoid repeat global lookups
         cls = self.__class__
@@ -434,7 +423,7 @@ class Model(metaclass=ModelBase):
                     "are not allowed in fields."
                 )
 
-        db_instance_qs = self.__class__._base_manager.get_queryset().filter(id=self.id)
+        db_instance_qs = self.__class__._meta.base_queryset.filter(id=self.id)
 
         # Use provided fields, if not set then reload all non-deferred fields.
         deferred_fields = self.get_deferred_fields()
@@ -617,7 +606,7 @@ class Model(metaclass=ModelBase):
             force_insert = True
         # If possible, try an UPDATE. If that doesn't update anything, do an INSERT.
         if id_set and not force_insert:
-            base_qs = cls._base_manager
+            base_qs = meta.base_queryset
             values = [
                 (
                     f,
@@ -641,7 +630,7 @@ class Model(metaclass=ModelBase):
                 fields = [f for f in fields if f is not id_field]
 
             returning_fields = meta.db_returning_fields
-            results = self._do_insert(cls._base_manager, fields, returning_fields, raw)
+            results = self._do_insert(meta.base_queryset, fields, returning_fields, raw)
             if results:
                 for value, field in zip(results[0], returning_fields):
                     setattr(self, field.attname, value)
@@ -738,7 +727,7 @@ class Model(metaclass=ModelBase):
         q = Q.create([(field.name, param), (f"id__{op}", self.id)], connector=Q.AND)
         q = Q.create([q, (f"{field.name}__{op}", param)], connector=Q.OR)
         qs = (
-            self.__class__._default_manager.filter(**kwargs)
+            self.__class__.query.filter(**kwargs)
             .filter(q)
             .order_by(f"{order}{field.name}", f"{order}id")
         )
@@ -836,7 +825,7 @@ class Model(metaclass=ModelBase):
             if len(unique_check) != len(lookup_kwargs):
                 continue
 
-            qs = model_class._default_manager.filter(**lookup_kwargs)
+            qs = model_class.query.filter(**lookup_kwargs)
 
             # Exclude the current object from the query if we are editing an
             # instance (as opposed to creating a new one)
@@ -995,9 +984,7 @@ class Model(metaclass=ModelBase):
 
     @classmethod
     def check(cls, **kwargs):
-        errors = [
-            *cls._check_managers(**kwargs),
-        ]
+        errors = []
 
         database = kwargs.get("database", False)
         errors += [
@@ -1045,14 +1032,6 @@ class Model(metaclass=ModelBase):
             )
         return errors
 
-    @classmethod
-    def _check_managers(cls, **kwargs):
-        """Perform all manager checks."""
-        errors = []
-        for manager in cls._meta.managers:
-            errors.extend(manager.check(**kwargs))
-        return errors
-
     @classmethod
     def _check_fields(cls, **kwargs):
         """Perform all field checks."""
