@@ -1,17 +1,15 @@
 import json
-import warnings
 
 from plain import exceptions, preflight
 from plain.models import expressions, lookups
 from plain.models.constants import LOOKUP_SEP
-from plain.models.db import NotSupportedError, connections, router
+from plain.models.db import NotSupportedError, db_connection
 from plain.models.fields import TextField
 from plain.models.lookups import (
     FieldGetDbPrepValueMixin,
     PostgresOperatorLookup,
     Transform,
 )
-from plain.utils.deprecation import RemovedInDjango51Warning
 
 from . import Field
 from .mixins import CheckFieldDefaultMixin
@@ -29,7 +27,7 @@ class JSONField(CheckFieldDefaultMixin, Field):
 
     def __init__(
         self,
-        name=None,
+        *,
         encoder=None,
         decoder=None,
         **kwargs,
@@ -40,32 +38,29 @@ class JSONField(CheckFieldDefaultMixin, Field):
             raise ValueError("The decoder parameter must be a callable object.")
         self.encoder = encoder
         self.decoder = decoder
-        super().__init__(name, **kwargs)
+        super().__init__(**kwargs)
 
     def check(self, **kwargs):
         errors = super().check(**kwargs)
-        databases = kwargs.get("databases") or []
-        errors.extend(self._check_supported(databases))
+        database = kwargs.get("database", False)
+        errors.extend(self._check_supported(database))
         return errors
 
-    def _check_supported(self, databases):
+    def _check_supported(self, database):
         errors = []
-        for db in databases:
-            if not router.allow_migrate_model(db, self.model):
-                continue
-            connection = connections[db]
+        if database:
             if (
                 self.model._meta.required_db_vendor
-                and self.model._meta.required_db_vendor != connection.vendor
+                and self.model._meta.required_db_vendor != db_connection.vendor
             ):
-                continue
+                return errors
             if not (
                 "supports_json_field" in self.model._meta.required_db_features
-                or connection.features.supports_json_field
+                or db_connection.features.supports_json_field
             ):
                 errors.append(
                     preflight.Error(
-                        "%s does not support JSONFields." % connection.display_name,
+                        f"{db_connection.display_name} does not support JSONFields.",
                         obj=self.model,
                         id="fields.E180",
                     )
@@ -96,31 +91,10 @@ class JSONField(CheckFieldDefaultMixin, Field):
         return "JSONField"
 
     def get_db_prep_value(self, value, connection, prepared=False):
-        # RemovedInDjango51Warning: When the deprecation ends, replace with:
-        # if (
-        #     isinstance(value, expressions.Value)
-        #     and isinstance(value.output_field, JSONField)
-        # ):
-        #     value = value.value
-        # elif hasattr(value, "as_sql"): ...
-        if isinstance(value, expressions.Value):
-            if isinstance(value.value, str) and not isinstance(
-                value.output_field, JSONField
-            ):
-                try:
-                    value = json.loads(value.value, cls=self.decoder)
-                except json.JSONDecodeError:
-                    value = value.value
-                else:
-                    warnings.warn(
-                        "Providing an encoded JSON string via Value() is deprecated. "
-                        f"Use Value({value!r}, output_field=JSONField()) instead.",
-                        category=RemovedInDjango51Warning,
-                    )
-            elif isinstance(value.output_field, JSONField):
-                value = value.value
-            else:
-                return value
+        if isinstance(value, expressions.Value) and isinstance(
+            value.output_field, JSONField
+        ):
+            value = value.value
         elif hasattr(value, "as_sql"):
             return value
         return connection.ops.adapt_json_value(value, self.encoder)
@@ -160,7 +134,7 @@ def compile_json_path(key_transforms, include_root=True):
             path.append(".")
             path.append(json.dumps(key_transform))
         else:
-            path.append("[%s]" % num)
+            path.append(f"[{num}]")
     return "".join(path)
 
 
@@ -199,7 +173,7 @@ class HasKeyLookup(PostgresOperatorLookup):
 
     def compile_json_path_final_key(self, key_transform):
         # Compile the final key without interpreting ints as array elements.
-        return ".%s" % json.dumps(key_transform)
+        return f".{json.dumps(key_transform)}"
 
     def as_sql(self, compiler, connection, template=None):
         # Process JSON path from the left-hand side.
@@ -228,7 +202,7 @@ class HasKeyLookup(PostgresOperatorLookup):
             rhs_params.append(lhs_json_path + rhs_json_path)
         # Add condition for each key.
         if self.logical_operator:
-            sql = "(%s)" % self.logical_operator.join([sql] * len(rhs_params))
+            sql = f"({self.logical_operator.join([sql] * len(rhs_params))})"
         return sql, tuple(lhs_params) + tuple(rhs_params)
 
     def as_mysql(self, compiler, connection):
@@ -287,13 +261,13 @@ class CaseInsensitiveMixin:
     def process_lhs(self, compiler, connection):
         lhs, lhs_params = super().process_lhs(compiler, connection)
         if connection.vendor == "mysql":
-            return "LOWER(%s)" % lhs, lhs_params
+            return f"LOWER({lhs})", lhs_params
         return lhs, lhs_params
 
     def process_rhs(self, compiler, connection):
         rhs, rhs_params = super().process_rhs(compiler, connection)
         if connection.vendor == "mysql":
-            return "LOWER(%s)" % rhs, rhs_params
+            return f"LOWER({rhs})", rhs_params
         return rhs, rhs_params
 
 
@@ -344,7 +318,7 @@ class KeyTransform(Transform):
     def as_mysql(self, compiler, connection):
         lhs, params, key_transforms = self.preprocess_lhs(compiler, connection)
         json_path = compile_json_path(key_transforms)
-        return "JSON_EXTRACT(%s, %%s)" % lhs, tuple(params) + (json_path,)
+        return f"JSON_EXTRACT({lhs}, %s)", tuple(params) + (json_path,)
 
     def as_postgresql(self, compiler, connection):
         lhs, params, key_transforms = self.preprocess_lhs(compiler, connection)
@@ -378,11 +352,11 @@ class KeyTextTransform(KeyTransform):
         if connection.mysql_is_mariadb:
             # MariaDB doesn't support -> and ->> operators (see MDEV-13594).
             sql, params = super().as_mysql(compiler, connection)
-            return "JSON_UNQUOTE(%s)" % sql, params
+            return f"JSON_UNQUOTE({sql})", params
         else:
             lhs, params, key_transforms = self.preprocess_lhs(compiler, connection)
             json_path = compile_json_path(key_transforms)
-            return "(%s ->> %%s)" % lhs, tuple(params) + (json_path,)
+            return f"({lhs} ->> %s)", tuple(params) + (json_path,)
 
     @classmethod
     def from_lookup(cls, lookup):
@@ -450,7 +424,7 @@ class KeyTransformIn(lookups.In):
             ):
                 sql = "JSON_EXTRACT(%s, '$')"
         if connection.vendor == "mysql" and connection.mysql_is_mariadb:
-            sql = "JSON_UNQUOTE(%s)" % sql
+            sql = f"JSON_UNQUOTE({sql})"
         return sql, params
 
 
