@@ -166,14 +166,14 @@ class ForeignObjectRel(FieldCacheMixin):
         initially for utilization by RelatedFieldListFilter.
         """
         limit_choices_to = limit_choices_to or self.limit_choices_to
-        qs = self.related_model._default_manager.complex_filter(limit_choices_to)
+        qs = self.related_model.query.complex_filter(limit_choices_to)
         if ordering:
             qs = qs.order_by(*ordering)
         return (blank_choice if include_blank else []) + [(x.id, str(x)) for x in qs]
 
     def is_hidden(self):
         """Should the related object be hidden?"""
-        return bool(self.related_name) and self.related_name[-1] == "+"
+        return not self.related_name
 
     def get_joining_columns(self):
         return self.field.get_reverse_joining_columns()
@@ -194,20 +194,17 @@ class ForeignObjectRel(FieldCacheMixin):
     def get_accessor_name(self, model=None):
         # This method encapsulates the logic that decides what name to give an
         # accessor descriptor that retrieves related many-to-one or
-        # many-to-many objects. It uses the lowercased object_name + "_set",
-        # but this can be overridden with the "related_name" option. Due to
-        # backwards compatibility ModelForms need to be able to provide an
-        # alternate model. See BaseInlineFormSet.get_default_prefix().
-        opts = model._meta if model else self.related_model._meta
+        # many-to-many objects.
         model = model or self.related_model
         if self.multiple:
             # If this is a symmetrical m2m relation on self, there is no
             # reverse accessor.
             if self.symmetrical and model == self.model:
                 return None
+        # Only return a name if related_name is explicitly set
         if self.related_name:
             return self.related_name
-        return opts.model_name + ("_set" if self.multiple else "")
+        return None
 
     def get_path_info(self, filtered_relation=None):
         if filtered_relation:
