@@ -1,5 +1,4 @@
 import bisect
-import copy
 import inspect
 from collections import defaultdict
 from functools import cached_property
@@ -9,7 +8,7 @@ from plain.models import models_registry
 from plain.models.constraints import UniqueConstraint
 from plain.models.db import db_connection
 from plain.models.fields import PrimaryKeyField
-from plain.models.manager import Manager
+from plain.models.query import QuerySet
 from plain.utils.datastructures import ImmutableList
 
 PROXY_PARENTS = object()
@@ -24,15 +23,12 @@ IMMUTABLE_WARNING = (
 DEFAULT_NAMES = (
     "db_table",
     "db_table_comment",
+    "queryset_class",
     "ordering",
-    "get_latest_by",
     "package_label",
     "models_registry",
-    "default_related_name",
     "required_db_features",
     "required_db_vendor",
-    "base_manager_name",
-    "default_manager_name",
     "indexes",
     "constraints",
 )
@@ -50,10 +46,8 @@ class Options:
         "local_concrete_fields",
         "_non_pk_concrete_field_names",
         "_forward_fields_map",
-        "managers",
-        "managers_map",
-        "base_manager",
-        "default_manager",
+        "base_queryset",
+        "queryset",
     }
     REVERSE_PROPERTIES = {"related_objects", "fields_map", "_relation_tree"}
 
@@ -63,9 +57,7 @@ class Options:
         self._get_fields_cache = {}
         self.local_fields = []
         self.local_many_to_many = []
-        self.local_managers = []
-        self.base_manager_name = None
-        self.default_manager_name = None
+        self.queryset_class = None
         self.model_name = None
         self.db_table = ""
         self.db_table_comment = ""
@@ -74,7 +66,6 @@ class Options:
         self.constraints = []
         self.object_name = None
         self.package_label = package_label
-        self.get_latest_by = None
         self.required_db_features = []
         self.required_db_vendor = None
         self.meta = meta
@@ -91,8 +82,6 @@ class Options:
         # A custom app registry to use, if you're making a separate model set.
         self.models_registry = self.default_models_registry
 
-        self.default_related_name = None
-
     @property
     def label(self):
         return f"{self.package_label}.{self.object_name}"
@@ -171,10 +160,6 @@ class Options:
         if not any(f.name == "id" for f in self.local_fields):
             model.add_to_class("id", PrimaryKeyField())
 
-    def add_manager(self, manager):
-        self.local_managers.append(manager)
-        self._expire_cache()
-
     def add_field(self, field, private=False):
         # Insert the given field in the order in which it was created, using
         # the "creation_counter" attribute of the field.
@@ -226,75 +211,25 @@ class Options:
             )
         return True
 
-    @cached_property
-    def managers(self):
-        managers = []
-        seen_managers = set()
-        bases = (b for b in self.model.mro() if hasattr(b, "_meta"))
-        for depth, base in enumerate(bases):
-            for manager in base._meta.local_managers:
-                if manager.name in seen_managers:
-                    continue
+    @property
+    def base_queryset(self):
+        """
+        The base queryset is used by Plain's internal operations like cascading
+        deletes, migrations, and related object lookups. It provides access to
+        all objects in the database without any filtering, ensuring Plain can
+        always see the complete dataset when performing framework operations.
 
-                manager = copy.copy(manager)
-                manager.model = self.model
-                seen_managers.add(manager.name)
-                managers.append((depth, manager.creation_counter, manager))
+        Unlike user-defined querysets which may filter results (e.g. only active
+        objects), the base queryset must never filter out rows to prevent
+        incomplete results in related queries.
+        """
+        return QuerySet(model=self.model)
 
-        return make_immutable_fields_list(
-            "managers",
-            (m[2] for m in sorted(managers)),
-        )
-
-    @cached_property
-    def managers_map(self):
-        return {manager.name: manager for manager in self.managers}
-
-    @cached_property
-    def base_manager(self):
-        base_manager_name = self.base_manager_name
-        if not base_manager_name:
-            # Get the first parent's base_manager_name if there's one.
-            for parent in self.model.mro()[1:]:
-                if hasattr(parent, "_meta"):
-                    if parent._base_manager.name != "_base_manager":
-                        base_manager_name = parent._base_manager.name
-                    break
-
-        if base_manager_name:
-            try:
-                return self.managers_map[base_manager_name]
-            except KeyError:
-                raise ValueError(
-                    f"{self.object_name} has no manager named {base_manager_name!r}"
-                )
-
-        manager = Manager()
-        manager.name = "_base_manager"
-        manager.model = self.model
-        manager.auto_created = True
-        return manager
-
-    @cached_property
-    def default_manager(self):
-        default_manager_name = self.default_manager_name
-        if not default_manager_name and not self.local_managers:
-            # Get the first parent's default_manager_name if there's one.
-            for parent in self.model.mro()[1:]:
-                if hasattr(parent, "_meta"):
-                    default_manager_name = parent._meta.default_manager_name
-                    break
-
-        if default_manager_name:
-            try:
-                return self.managers_map[default_manager_name]
-            except KeyError:
-                raise ValueError(
-                    f"{self.object_name} has no manager named {default_manager_name!r}"
-                )
-
-        if self.managers:
-            return self.managers[0]
+    @property
+    def queryset(self):
+        if self.queryset_class:
+            return self.queryset_class(model=self.model)
+        return QuerySet(model=self.model)
 
     @cached_property
     def fields(self):
