@@ -255,9 +255,8 @@ class FlatValuesListIterable(BaseIterable):
 class QuerySet:
     """Represent a lazy database lookup for a set of objects."""
 
-    def __init__(self, model=None, query=None, hints=None):
+    def __init__(self, *, model=None, query=None):
         self.model = model
-        self._hints = hints or {}
         self._query = query or sql.Query(self.model)
         self._result_cache = None
         self._sticky_filter = False
@@ -284,17 +283,6 @@ class QuerySet:
             self._iterable_class = ValuesIterable
         self._query = value
 
-    def as_manager(cls):
-        # Address the circular dependency between `Queryset` and `Manager`.
-        from plain.models.manager import Manager
-
-        manager = Manager.from_queryset(cls)()
-        manager._built_with_as_manager = True
-        return manager
-
-    as_manager.queryset_only = True
-    as_manager = classmethod(as_manager)
-
     ########################
     # PYTHON MAGIC METHODS #
     ########################
@@ -425,12 +413,12 @@ class QuerySet:
         query = (
             self
             if self.query.can_filter()
-            else self.model._base_manager.filter(id__in=self.values("id"))
+            else self.model._meta.base_queryset.filter(id__in=self.values("id"))
         )
         combined = query._chain()
         combined._merge_known_related_objects(other)
         if not other.query.can_filter():
-            other = other.model._base_manager.filter(id__in=other.values("id"))
+            other = other.model._meta.base_queryset.filter(id__in=other.values("id"))
         combined.query.combine(other.query, sql.OR)
         return combined
 
@@ -444,12 +432,12 @@ class QuerySet:
         query = (
             self
             if self.query.can_filter()
-            else self.model._base_manager.filter(id__in=self.values("id"))
+            else self.model._meta.base_queryset.filter(id__in=self.values("id"))
         )
         combined = query._chain()
         combined._merge_known_related_objects(other)
         if not other.query.can_filter():
-            other = other.model._base_manager.filter(id__in=other.values("id"))
+            other = other.model._meta.base_queryset.filter(id__in=other.values("id"))
         combined.query.combine(other.query, sql.XOR)
         return combined
 
@@ -873,59 +861,14 @@ class QuerySet:
             )
         return params
 
-    def _earliest(self, *fields):
-        """
-        Return the earliest object according to fields (if given) or by the
-        model's Meta.get_latest_by.
-        """
-        if fields:
-            order_by = fields
-        else:
-            order_by = getattr(self.model._meta, "get_latest_by")
-            if order_by and not isinstance(order_by, tuple | list):
-                order_by = (order_by,)
-        if order_by is None:
-            raise ValueError(
-                "earliest() and latest() require either fields as positional "
-                "arguments or 'get_latest_by' in the model's Meta."
-            )
-        obj = self._chain()
-        obj.query.set_limits(high=1)
-        obj.query.clear_ordering(force=True)
-        obj.query.add_ordering(*order_by)
-        return obj.get()
-
-    def earliest(self, *fields):
-        if self.query.is_sliced:
-            raise TypeError("Cannot change a query once a slice has been taken.")
-        return self._earliest(*fields)
-
-    def latest(self, *fields):
-        """
-        Return the latest object according to fields (if given) or by the
-        model's Meta.get_latest_by.
-        """
-        if self.query.is_sliced:
-            raise TypeError("Cannot change a query once a slice has been taken.")
-        return self.reverse()._earliest(*fields)
-
     def first(self):
         """Return the first object of a query or None if no match is found."""
-        if self.ordered:
-            queryset = self
-        else:
-            self._check_ordering_first_last_queryset_aggregation(method="first")
-            queryset = self.order_by("id")
-        for obj in queryset[:1]:
+        for obj in self[:1]:
             return obj
 
     def last(self):
         """Return the last object of a query or None if no match is found."""
-        if self.ordered:
-            queryset = self.reverse()
-        else:
-            self._check_ordering_first_last_queryset_aggregation(method="last")
-            queryset = self.order_by("-id")
+        queryset = self.reverse()
         for obj in queryset[:1]:
             return obj
 
@@ -1002,8 +945,6 @@ class QuerySet:
         self._result_cache = None
         return deleted, _rows_count
 
-    delete.queryset_only = True
-
     def _raw_delete(self):
         """
         Delete objects found from the given queryset in single direct SQL
@@ -1072,8 +1013,6 @@ class QuerySet:
         self._result_cache = None
         return query.get_compiler().execute_sql(CURSOR)
 
-    _update.queryset_only = False
-
     def exists(self):
         """
         Return True if the QuerySet would have any results, False otherwise.
@@ -1246,7 +1185,7 @@ class QuerySet:
     def all(self):
         """
         Return a new QuerySet that is a copy of the current one. This allows a
-        QuerySet to proxy for a model manager in some cases.
+        QuerySet to proxy for a model queryset in some cases.
         """
         return self._chain()
 
@@ -1610,8 +1549,6 @@ class QuerySet:
         query.insert_values(fields, objs, raw=raw)
         return query.get_compiler().execute_sql(returning_fields)
 
-    _insert.queryset_only = False
-
     def _batched_insert(
         self,
         objs,
@@ -1667,7 +1604,6 @@ class QuerySet:
         c = self.__class__(
             model=self.model,
             query=self.query.chain(),
-            hints=self._hints,
         )
         c._sticky_filter = self._sticky_filter
         c._for_write = self._for_write
@@ -1723,15 +1659,6 @@ class QuerySet:
         query = self.query.resolve_expression(*args, **kwargs)
         return query
 
-    resolve_expression.queryset_only = True
-
-    def _add_hints(self, **hints):
-        """
-        Update hinting information for use by routers. Add new key/values or
-        overwrite existing key/values.
-        """
-        self._hints.update(hints)
-
     def _has_filters(self):
         """
         Check if this QuerySet has any filtering going on. This isn't
@@ -1763,16 +1690,6 @@ class QuerySet:
         if self.query.combinator or other.query.combinator:
             raise TypeError(f"Cannot use {operator_} operator with combined queryset.")
 
-    def _check_ordering_first_last_queryset_aggregation(self, method):
-        if isinstance(self.query.group_by, tuple) and not any(
-            col.output_field is self.model._meta.get_field("id")
-            for col in self.query.group_by
-        ):
-            raise TypeError(
-                f"Cannot use QuerySet.{method}() on an unordered queryset performing "
-                f"aggregation. Add an ordering with order_by()."
-            )
-
 
 class InstanceCheckMeta(type):
     def __instancecheck__(self, instance):
@@ -1802,11 +1719,9 @@ class RawQuerySet:
         query=None,
         params=(),
         translations=None,
-        hints=None,
     ):
         self.raw_query = raw_query
         self.model = model
-        self._hints = hints or {}
         self.query = query or sql.RawQuery(sql=raw_query, params=params)
         self.params = params
         self.translations = translations or {}
@@ -1852,7 +1767,6 @@ class RawQuerySet:
             query=self.query,
             params=self.params,
             translations=self.translations,
-            hints=self._hints,
         )
         c._prefetch_related_lookups = self._prefetch_related_lookups[:]
         return c
@@ -2235,7 +2149,7 @@ def prefetch_one_level(instances, prefetcher, lookup, level):
         for additional_lookup in getattr(rel_qs, "_prefetch_related_lookups", ())
     ]
     if additional_lookups:
-        # Don't need to clone because the manager should have given us a fresh
+        # Don't need to clone because the queryset should have given us a fresh
         # instance, so we access an internal instead of using public interface
         # for performance reasons.
         rel_qs._prefetch_related_lookups = ()
@@ -2286,11 +2200,11 @@ def prefetch_one_level(instances, prefetcher, lookup, level):
             if as_attr:
                 setattr(obj, to_attr, vals)
             else:
-                manager = getattr(obj, to_attr)
+                queryset = getattr(obj, to_attr)
                 if leaf and lookup.queryset is not None:
-                    qs = manager._apply_rel_filters(lookup.queryset)
+                    qs = queryset._apply_rel_filters(lookup.queryset)
                 else:
-                    qs = manager.get_queryset()
+                    qs = queryset.__class__(model=queryset.model)
                 qs._result_cache = vals
                 # We don't want the individual qs doing prefetch_related now,
                 # since we have merged this into the current work.
