@@ -23,7 +23,9 @@ class DeleteParent(models.Model):
 
 @models.register_model
 class ChildCascade(models.Model):
-    parent = models.ForeignKey(DeleteParent, on_delete=models.CASCADE)
+    parent = models.ForeignKey(
+        DeleteParent, on_delete=models.CASCADE, related_name="childcascade_set"
+    )
 
 
 @models.register_model
@@ -48,7 +50,7 @@ class ChildSetNull(models.Model):
 @models.register_model
 class ChildSetDefault(models.Model):
     def default_parent_id():
-        return DeleteParent.objects.get(name="default").id
+        return DeleteParent.query.get(name="default").id
 
     parent = models.ForeignKey(
         DeleteParent,
@@ -60,3 +62,41 @@ class ChildSetDefault(models.Model):
 @models.register_model
 class ChildDoNothing(models.Model):
     parent = models.ForeignKey(DeleteParent, on_delete=models.DO_NOTHING)
+
+
+# Models for testing QuerySet assignment behavior
+@models.register_model
+class DefaultQuerySetModel(models.Model):
+    """Model that uses the default objects QuerySet."""
+
+    name = models.CharField(max_length=100)
+
+
+class CustomQuerySet(models.QuerySet):
+    def get_custom(self):
+        return self.filter(name__startswith="custom")
+
+
+class CustomSpecialQuerySet(models.QuerySet):
+    def get_custom_qs(self):
+        return self.filter(name__startswith="custom")
+
+
+@models.register_model
+class CustomQuerySetModel(models.Model):
+    """Model with a custom QuerySet."""
+
+    name = models.CharField(max_length=100)
+
+    class Meta:
+        queryset_class = CustomQuerySet
+
+
+@models.register_model
+class CustomSpecialQuerySetModel(models.Model):
+    """Model with a custom special QuerySet."""
+
+    name = models.CharField(max_length=100)
+
+    class Meta:
+        queryset_class = CustomSpecialQuerySet
