@@ -15,41 +15,41 @@ from plain.models import (
 
 
 def _create_parents():
-    default_parent = DeleteParent.objects.create(name="default")
-    parent = DeleteParent.objects.create(name="parent")
+    default_parent = DeleteParent.query.create(name="default")
+    parent = DeleteParent.query.create(name="parent")
     return default_parent, parent
 
 
 def test_cascade_delete(db):
     _create_parents()
-    parent = DeleteParent.objects.get(name="parent")
-    ChildCascade.objects.create(parent=parent)
+    parent = DeleteParent.query.get(name="parent")
+    ChildCascade.query.create(parent=parent)
     parent.delete()
-    assert ChildCascade.objects.count() == 0
+    assert ChildCascade.query.count() == 0
 
 
 def test_protect_delete(db):
     _create_parents()
-    parent = DeleteParent.objects.get(name="parent")
-    ChildProtect.objects.create(parent=parent)
+    parent = DeleteParent.query.get(name="parent")
+    ChildProtect.query.create(parent=parent)
     with pytest.raises(ProtectedError):
         parent.delete()
-    assert DeleteParent.objects.filter(id=parent.id).exists()
+    assert DeleteParent.query.filter(id=parent.id).exists()
 
 
 def test_restrict_delete(db):
     _create_parents()
-    parent = DeleteParent.objects.get(name="parent")
-    ChildRestrict.objects.create(parent=parent)
+    parent = DeleteParent.query.get(name="parent")
+    ChildRestrict.query.create(parent=parent)
     with pytest.raises(RestrictedError):
         parent.delete()
-    assert DeleteParent.objects.filter(id=parent.id).exists()
+    assert DeleteParent.query.filter(id=parent.id).exists()
 
 
 def test_set_null_delete(db):
     _create_parents()
-    parent = DeleteParent.objects.get(name="parent")
-    child = ChildSetNull.objects.create(parent=parent)
+    parent = DeleteParent.query.get(name="parent")
+    child = ChildSetNull.query.create(parent=parent)
     parent.delete()
     child.refresh_from_db()
     assert child.parent_id is None
@@ -57,7 +57,7 @@ def test_set_null_delete(db):
 
 def test_set_default_delete(db):
     default_parent, parent = _create_parents()
-    child = ChildSetDefault.objects.create(parent=parent)
+    child = ChildSetDefault.query.create(parent=parent)
     parent.delete()
     child.refresh_from_db()
     assert child.parent_id == default_parent.id
@@ -65,7 +65,7 @@ def test_set_default_delete(db):
 
 # def test_do_nothing_delete(db):
 #     default_parent, parent = _create_parents()
-#     child = ChildDoNothing.objects.create(parent=parent)
+#     child = ChildDoNothing.query.create(parent=parent)
 #     parent.delete()
 #     with pytest.raises(IntegrityError):
 #         db_connection.check_constraints()
